@@ -3,6 +3,7 @@ package flag
 import (
 	"context"
 	"slices"
+	"strings"
 	"time"
 
 	"github.com/spf13/pflag"
@@ -92,6 +93,21 @@ func GetStringSlice(ctx context.Context, name string) []string {
 	}
 }
 
+// GetStringSlice returns the values of the named string flag ctx carries. Can
+// be comma separated or passed "by repeated flags": `--flag x,y` is equivalent
+// to `--flag x --flag y`. Strings are trimmed of extra whitespace and empty
+// strings are removed.
+func GetNonEmptyStringSlice(ctx context.Context, name string) []string {
+	if v, err := FromContext(ctx).GetStringSlice(name); err != nil {
+		return []string{}
+	} else {
+		for i := range v {
+			v[i] = strings.TrimSpace(v[i])
+		}
+		return slices.DeleteFunc(v, func(s string) bool { return s == "" })
+	}
+}
+
 // GetDuration returns the value of the named duration flag ctx carries.
 func GetDuration(ctx context.Context, name string) time.Duration {
 	if v, err := FromContext(ctx).GetDuration(name); err != nil {
