@@ -143,10 +143,10 @@ func configureRails(sourceDir string, config *ScannerConfig) (*SourceInfo, error
 	redis := false
 	files, err := filepath.Glob("app/channels/*.rb")
 	if err == nil && len(files) > 0 {
-		redis = true
+		redis = !checksPass(sourceDir, dirContains("Gemfile", "solid_cable"))
 	}
 
-	if redis == false {
+	if !redis && !checksPass(sourceDir, dirContains("Gemfile", "solid_cable")) {
 		files, err = filepath.Glob("app/views/*")
 		if err == nil && len(files) > 0 {
 			for _, file := range files {
@@ -159,7 +159,7 @@ func configureRails(sourceDir string, config *ScannerConfig) (*SourceInfo, error
 	}
 
 	// enable redis if redis is used for caching
-	if !redis {
+	if !redis && !checksPass(sourceDir, dirContains("Gemfile", "solid_queue")) {
 		prodEnv, err := os.ReadFile("config/environments/production.rb")
 		if err == nil && strings.Contains(string(prodEnv), "redis") {
 			redis = true
